@@ -872,6 +872,13 @@ void PrgBody::removeHead(PrgHead* h, EdgeType t) {
 	}
 }
 
+bool PrgBody::hasHead(PrgHead* h, EdgeType t) const {
+	if (!hasHeads()) { return false;  }
+	PrgEdge x = PrgEdge::newEdge(h->id(), t, h->isAtom() ? PrgEdge::ATOM_NODE : PrgEdge::DISJ_NODE);
+	head_iterator it = sHead_ != 0 || !extHead() ? std::find(heads_begin(), heads_end(), x) : std::lower_bound(heads_begin(), heads_end(), x);
+	return it != heads_end() && *it == x;
+}
+
 bool PrgBody::eraseHead(PrgEdge h) {
 	PrgEdge* it = const_cast<PrgEdge*>(std::find(heads_begin(), heads_end(), h));
 	if (it != heads_end()) {
@@ -1120,10 +1127,16 @@ bool PrgBody::mergeHeads(LogicProgram& prg, PrgBody& heads, bool strong, bool si
 			ok = simplifyHeadsImpl(prg, *this, rs, strong);
 		}
 		else {
-			assert(heads.sHead_ == 0 && "Heads to merge not simplified!");
 			heads.prepareSimplifyHeads(prg, rs);
-			ok = simplifyHeadsImpl(prg, *this, rs, strong) && heads.simplifyHeadsImpl(prg, *this, rs, strong);
-			assert(ok || heads.heads_begin() == heads.heads_end());
+			if (!simplifyHeadsImpl(prg, *this, rs, strong) && !assignValue(value_false)) {
+				rs.clearAll();
+				return false;
+			}
+			ok = heads.simplifyHeadsImpl(prg, *this, rs, strong);
+			if (!ok && (!heads.assignValue(value_false) || !heads.propagateValue(prg, false))) {
+				rs.clearAll();
+				return false;
+			}
 		}
 		// clear temporary flags & reestablish ordering
 		std::sort(const_cast<PrgEdge*>(heads_begin()), const_cast<PrgEdge*>(heads_end()));
