@@ -360,6 +360,9 @@ void ParallelSolve::joinThreads() {
 		}
 		destroyThread(i);
 	}
+	if (shared_->complete()) {
+		enumerator().commitComplete();
+	}
 	// detach master only after all client threads are done
 	thread_[masterId]->detach(*shared_->ctx, shared_->interrupt());
 	thread_[masterId]->setError(!shared_->interrupt() ? thread_[masterId]->error() : ec);
@@ -462,10 +465,10 @@ bool ParallelSolve::doInterrupt() {
 // tries to get new work for the given solver
 bool ParallelSolve::requestWork(Solver& s, PathPtr& out) { 
 	const LitVec* a = 0;
-	while (!shared_->terminate()) {
+	for (int popped = 0; !shared_->terminate();) {
 		// only clear path and stop conflict - we don't propagate() here
 		// because we would then have to handle any eventual conflicts
-		if (!s.popRootLevel(s.rootLevel())) {
+		if (++popped == 1 && !s.popRootLevel(s.rootLevel())) {
 			// s has a real top-level conflict - problem is unsat
 			terminate(s, true);
 		}
@@ -485,6 +488,7 @@ bool ParallelSolve::requestWork(Solver& s, PathPtr& out) {
 			// s now has a conflict - either an artifical stop conflict
 			// or a real conflict - we'll handle it in the next iteration
 			// via the call to popRootLevel()
+			popped = 0;
 		}
 		else if (shared_->allowSplit()) {
 			// gp mode is active - request a split	
